<!--
 * @Author: liulin liulin19981227@163.com
 * @Date: 2023-03-25 23:22:29
 * @LastEditors: Do not edit
 * @LastEditTime: 2023-03-27 17:38:42
 * @FilePath: /work_artfess/yhxt_web/src/views/basicDataManagement/SectionManagement.vue
 * @Description: /frontPlat/sectionManagement/children
-->
<template>
    <div class="container">
        <div class="header">
            <div class="title">
                <i class="title-icon"></i>
                <span class="title-text">应急物资数据统计</span>
            </div>
            <i class="back-icon" @click="handleReset"></i>
        </div>
        <div class="table">
            <el-table
                :data="tableData"
                stripe
                v-loading="loading"
                @row-click="hanldeRowClick"
                @cell-click="handleCellClick"
                header-cell-class-name="custom-header-cell"
                cell-class-name="custom-cell"
            >
                <el-table-column label="序号" type="index" width="70" align="center">
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="name"
                    label="名称"
                    column-key="sectionManagement"
                >
                    <template v-slot="{row}">
                        <i class="el-icon-arrow-down" style="margin-right: 10px"></i>
                        {{ row.name }}
                    </template>
                </el-table-column>
                <el-table-column align="center" prop="countNum" label="物资库数量">
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.countNum) }}
                    </template>
                </el-table-column>
            </el-table>
            <div class="table-total">
                <span>{{ tableData.length + 1 }}</span>
                <span>总数</span>
                <span>{{ total.countNum || 0 }}</span>
            </div>
        </div>
    </div>
</template>

<script>
import utils from '@/utils' // thousandBit格式化千分位
const BigNumber = require('bignumber.js')
export default {
    data() {
        return {
            tableData: [],
            data: [],
            loading: false,
            pathName: '',
            type: '',
            total: {},
            utils: utils,
        }
    },
    created() {
        this.loadData()
    },
    watch: {
        tableData(newVal) {
            this.total.countNum = this.calculation('countNum', newVal)
        },
    },
    methods: {
        calculation(key, arr) {
            let total = new BigNumber(0)
            if (!key || arr.length === 0) return total
            arr.forEach((item) => {
                if (item[key]) {
                    total = total.plus(item[key])
                } else {
                    total = total.plus(0)
                }
            })
            return utils.thousandBit(total)
        },
        handleReset() {
            let length = this.data.length - 1
            if (length === 0) return
            this.tableData = this.data[this.data.length - 2]
            this.data.splice(length, 1)
        },
        hanldeRowClick(row) {
            if (row.chirldren.length == 0) {
                return this.$router.push({
                    name: 'emergencySuppliesChildren',
                    params: {
                        value: row,
                    },
                })
            }
            this.tableData = row.chirldren
            this.data.push(row.chirldren)
        },
        handleCellClick(row, column) {
            if (
                column.columnKey == '1' ||
                column.columnKey == '3' ||
                column.columnKey == '4'
            ) {
                this.type = column.columnKey
            }
        },
        loadData() {
            this.loading = true
            this.$http
                .post('${yhxt}/bizEmergeMaterialManagement/v1/getEmergeVo')
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
                .catch(() => {
                    this.loading = false
                })
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-table th.is-leaf {
    background-color: transparent !important;
}
/deep/ .el-table__row {
    background-color: #0b426e !important;
}
/deep/ .el-table__row--striped {
    background-color: #124873 !important;
}
/deep/ .el-table__header-wrapper {
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
}
/deep/ .el-table__body-wrapper {
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
}
/deep/ .el-table {
    background-color: transparent;
}
.container {
    padding: 30px;

    .header {
        height: 59px;
        width: 100%;
        display: flex;
        justify-content: space-between;
        border-bottom: 1px solid #4d7faf;
        .title {
            display: flex;
            height: 34px;
            align-items: center;
            .title-icon {
                display: block;
                width: 28px;
                height: 28px;
                background-image: url('../../assets/img/icon-标题@2x.png');
                background-size: 100% 100%;
            }
            .title-text {
                margin-left: 5px;
                height: 34px;
                font-size: 26px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 34px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
        .back-icon {
            margin-right: 10px;
            cursor: pointer;
            display: block;
            width: 40px;
            height: 40px;
            background-size: 100% 100%;
            background-image: url(../../assets//img/icon-返回@2x.png);
        }
    }

    .table {
        margin-top: 32px;
        width: 100%;
        /deep/ .custom-header-cell {
            background-color: #145080 !important;
            padding: 15px 0;
            .cell {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
            }
        }
        /deep/ .custom-cell {
            padding: 15px 0;
            cursor: pointer;
            .cell,
            div {
                font-size: 16px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 400;
                color: #e5f2ff;
            }
        }
        .table-total {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 64px;
            background-color: #145080;
            border-radius: 10px;
            margin-top: 8px;
            span {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
                text-align: center;
                &:nth-child(1) {
                    width: 70px;
                }
                &:not(:nth-child(1)) {
                    flex: 1;
                }
            }
        }
    }
}
</style>
